@@ -61,8 +61,6 @@ class ValidFormatJob:
         self.filter_columns: List[str] = t.filter_columns
         self.line_terminator: str = t.line_terminator
         self.partitions: Optional[int]
-        self.partition_limit = 10000
-        
         try:
             self.partitions = t.partitions
         except AttributeError:
@@ -162,7 +160,7 @@ class ValidFormatJob:
         if len(diff) == 0:
             return True
         else:
-            return InvalidJob(f"Filter columns {', '.join(diff)} not a subset of {', '.join(keys)}")
+            return InvalidJob(f"Columns {', '.join(diff)} not a subset of {', '.join(keys)}")
 
     def repartition(self, df: DataFrame, cluster_spec: ClusterSpec, partitions: Optional[int]) -> Union[DataFrame, InvalidJob]:
         size = df.size.compute()
@@ -225,18 +223,9 @@ class ValidFormatJob:
                     final = check
                 else:
                     pc = self.partition_columns
-                    invalid: Optional[str] = None
-                    for p in pc:
-                        size = len(df[p].unique())
-                        if size > self.partition_limit:
-                            invalid = f"{p} has length {size} which is greater than the partition limit {self.partition_limit}"
-                            break
-                    if invalid:
-                        final = InvalidJob(f"Partition Limit Too Large: {invalid}")
-                    else:
-                        a = df.groupby(pc).apply(write_partitioned, pc, meta=str).compute()
-                        results = list(a.values)
-                        final = ExecutedJob(", ".join(results))
+                    a = df.groupby(pc).apply(write_partitioned, pc, meta=str).compute()
+                    results = list(a.values)
+                    final = ExecutedJob(", ".join(results))
             else:
                 df = self.repartition(df, cluster_spec, self.partitions)
                 if isinstance(df, DataFrame):
