@@ -1,4 +1,4 @@
-from typing import List, Tuple, Optional, Union
+from typing import List, Tuple, Optional
 
 from distributed import Client
 from distributed.scheduler import WorkerState
@@ -15,6 +15,8 @@ class ClusterSpec:
             worker_specs: List[Tuple[int, int]] = list(map(lambda w: (w.memory_limit, w.ncores), workers))
             self.worker_specs = list(map(lambda s: WorkerSpec(*s), worker_specs))
         elif num_workers and desired_spec:
+            assert(desired_spec is not None)
+            assert(num_workers is not None)
             self.worker_specs = [desired_spec] * num_workers 
             
     def valid(self) -> bool:
@@ -26,8 +28,12 @@ class ClusterSpec:
     def max_partition_size(self) -> Optional[int]:
         if self.worker_specs:
             return min(list(map(lambda s: s.memory, self.worker_specs)))
+        else:
+            return None
     
     def num_workers(self) -> Optional[int]:
         if self.worker_specs:
             return len(self.worker_specs)
+        else:
+            return None
     
